@@ -52,7 +52,7 @@ public:
             kget = new MainWindow(!parser->isSet("showDropTarget"), parser->isSet("startWithoutAnimation"), false);
 #endif
 
-            DBusKGetWrapper *wrapper = new DBusKGetWrapper(kget);
+            auto *wrapper = new DBusKGetWrapper(kget);
             new MainAdaptor(wrapper);
             QDBusConnection::sessionBus().registerObject("/KGet", wrapper);
         } else {
@@ -82,7 +82,7 @@ public:
         return 0;
     }
 
-public slots:
+public Q_SLOTS:
     void slotActivateRequested (QStringList args, const QString & /*workingDir*/)
     {
         parser->parse(args);
