@@ -20,7 +20,7 @@
 #include <QTimer>
 #include <KNotification>
 #include <KIconLoader>
-#include <KDebug>
+#include <QDebug>
 
 const QString KGET_DBUS_SERVICE = "org.kde.kget";
 const QString KGET_DBUS_PATH = "/KGet";
