@@ -40,7 +40,7 @@ namespace kt
 		Q_OBJECT
 	public:
 		PeerView(QWidget* parent);
-		virtual ~PeerView();
+		~PeerView() override;
 
 		/// A peer has been added
 		void peerAdded(bt::PeerInterface* peer);
@@ -57,7 +57,7 @@ namespace kt
 		void saveState(KSharedConfigPtr cfg);
 		void loadState(KSharedConfigPtr cfg);
 		
-	private slots: 
+	private Q_SLOTS: 
 		void showContextMenu(const QPoint& pos);
 		void banPeer();
 		void kickPeer();
