@@ -280,7 +280,7 @@ namespace kt
 		if (file)
 			return;
 		
-		BDictNode* dict = dynamic_cast<BDictNode*>(n);
+		auto* dict = dynamic_cast<BDictNode*>(n);
 		if (!dict)
 			return;
 		
@@ -673,11 +673,11 @@ namespace kt
 	bt::TorrentFileInterface* TorrentFileTreeModel::indexToFile(const QModelIndex & idx)
 	{
 		if (!idx.isValid())
-			return 0;
+			return nullptr;
 		
 		Node* n = (Node*)idx.internalPointer();
 		if (!n)
-			return 0;
+			return nullptr;
 		
 		return n->file;
 	}
