@@ -45,7 +45,7 @@ namespace kt
 		Q_OBJECT
 	public:
 		WebSeedsTab(QWidget* parent);
-		virtual ~WebSeedsTab();
+		~WebSeedsTab() override;
 		
 		/**
 		 * Switch to a different torrent.
@@ -59,7 +59,7 @@ namespace kt
 		void saveState(KSharedConfigPtr cfg);
 		void loadState(KSharedConfigPtr cfg);
 		
-	private slots:
+	private Q_SLOTS:
 		void addWebSeed();
 		void removeWebSeed();
 		void onWebSeedTextChanged(const QString & ws);
