@@ -31,7 +31,7 @@ class BTTransferHandler : public TransferHandler
     Q_OBJECT
     public:
         BTTransferHandler(BTTransfer * transfer, Scheduler * scheduler);
-        virtual ~BTTransferHandler();
+        ~BTTransferHandler() override;
 
         int chunksTotal() const                         {return m_transfer->chunksTotal();}
         int chunksDownloaded() const                    {return m_transfer->chunksDownloaded();}
@@ -47,11 +47,11 @@ class BTTransferHandler : public TransferHandler
         void addTracker(QString url)                    {m_transfer->addTracker(url);}
         kt::Monitor* torrentMonitor() const;
 
-    public slots:
+    public Q_SLOTS:
         void createAdvancedDetails();
         void createScanDlg();
 
-    private slots:
+    private Q_SLOTS:
         void removeAdvancedDetails();
 
     private:
