@@ -60,7 +60,7 @@ class ChecksumSearch : public QObject
     Q_SIGNALS:
         void data(QString type, QString checksum);
 
-    private slots:
+    private Q_SLOTS:
         void slotResult(KJob *job);
         void slotData(KIO::Job *job, const QByteArray &data);
 
