@@ -53,7 +53,7 @@ AbstractMetalink::~AbstractMetalink()
 void AbstractMetalink::slotDataSourceFactoryChange(Transfer::ChangesFlags change)
 {
     if ((change & Tc_Status) | (change & Tc_TotalSize)) {
-        DataSourceFactory *factory = qobject_cast<DataSourceFactory*>(sender());
+        auto *factory = qobject_cast<DataSourceFactory*>(sender());
         if (change & Tc_Status) {
             bool changeStatus;
             updateStatus(factory, &changeStatus);
@@ -288,7 +288,7 @@ bool AbstractMetalink::repair(const QUrl &file)
 Verifier *AbstractMetalink::verifier(const QUrl &file)
 {
     if (!m_dataSourceFactory.contains(file)) {
-        return 0;
+        return nullptr;
     }
 
     return m_dataSourceFactory[file]->verifier();
@@ -297,7 +297,7 @@ Verifier *AbstractMetalink::verifier(const QUrl &file)
 Signature *AbstractMetalink::signature(const QUrl &file)
 {
     if (!m_dataSourceFactory.contains(file)) {
-        return 0;
+        return nullptr;
     }
 
     return m_dataSourceFactory[file]->signature();
@@ -478,7 +478,7 @@ void AbstractMetalink::filesSelected()
                     doDownload = false;
                 //ask the user, unless he has chosen overwriteAll before
                 } else if (!overwriteAll) {
-                    KIO::RenameDialog dlg(0, i18n("File already exists"), QUrl(index.data().toString()), dest,
+                    KIO::RenameDialog dlg(nullptr, i18n("File already exists"), QUrl(index.data().toString()), dest,
                                           KIO::RenameDialog_Options(KIO::RenameDialog_MultipleItems | KIO::RenameDialog_Overwrite | KIO::RenameDialog_Skip));
                     const int result = dlg.exec();
 
