@@ -180,7 +180,7 @@ bool MetalinkXml::metalinkInit(const QUrl &src, const QByteArray &data)
             QHash<QString, QString>::const_iterator itEnd = signatures.constEnd();
             for (it = signatures.constBegin(); it != itEnd; ++it) {
                 if (it.key().toLower() == "pgp") {
-                    dataFactory->signature()->setAsciiDetatchedSignature(*it);
+                    dataFactory->signature()->setAsciiDetachedSignature(*it);
                 }
             }
 
