@@ -11,7 +11,7 @@
 #ifndef TRAY_H
 #define TRAY_H
 
-#include <kstatusnotifieritem.h>
+#include <KStatusNotifierItem>
 
 class MainWindow;
 class KGet;
@@ -33,9 +33,8 @@ public:
     void setDownloading(bool downloading);
     bool isDownloading();
 
-private slots:
+private Q_SLOTS:
     void slotActivated();
-    void slotRestore(bool active);
 };
 
 #endif
